@@ -9,11 +9,21 @@ from .reporting import MetricsReporter
 from .models import EvaluationCriteria
 
 
-def inject(token, app, starting, ending, velocity, statuses, report):
+def inject(
+    token,
+    app,
+    starting,
+    ending,
+    detailed_builds,
+    detailed_timing,
+    emulate_velocity,
+    target_branch,
+    report_style,
+):
 
     bitrise = Bitrise(token)
     finder = ProjectFinder(bitrise)
-    analyser = BuildsAnalyser(bitrise, MetricsCruncher())
+    analyser = BuildsAnalyser(bitrise, MetricsCruncher(), target_branch)
 
     criteria = EvaluationCriteria(
         cli.validated_app(app),
@@ -21,6 +31,7 @@ def inject(token, app, starting, ending, velocity, statuses, report):
         cli.validated_date(ending, include_hours=True),
     )
 
-    reporter = MetricsReporter(criteria, velocity, statuses, cli.validated_report(report))
+    report = cli.validated_report(report_style)
+    reporter = MetricsReporter(criteria, detailed_builds, detailed_timing, emulate_velocity, report)
 
     return Application(finder, analyser, reporter, criteria)
